import pytest

from crapssim.bet import DontPass, Odds, PassLine, Place
from crapssim.strategy.examples import HammerLock
from crapssim.table import Table, TableUpdate


@pytest.mark.parametrize(
    "point, last_roll, strat_info, bets_before, dice_result, bets_after",
    [
        (None, None, None, [], None, [PassLine(amount=5.0), DontPass(amount=5.0)]),
        (
            4,
            4,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (2, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (5, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            4,
            {"mode": "place68"},
            [Place(6, amount=12.0), Place(8, amount=12.0)],
            (3, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            2,
            {"mode": "place68"},
            [],
            (1, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            3,
            {"mode": "place68"},
            [],
            (1, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            5,
            5,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            4,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
            ],
            (4, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place_inside"},
            [],
            (2, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (2, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (1, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            5,
            5,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (2, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (5, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
            ],
            (3, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            5,
            3,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (1, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            5,
            9,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
            ],
            (4, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
            ],
        ),
        (
            5,
            10,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
            ],
            (6, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
            ],
        ),
        (
            5,
            6,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
            ],
            (3, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "takedown"},
            [],
            (4, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            9,
            9,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (6, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            9,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            9,
            3,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (2, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            9,
            {"mode": "place68"},
            [Place(6, amount=12.0), Place(8, amount=12.0)],
            (5, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            4,
            4,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (1, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            10,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            2,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
            ],
            (5, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            None,
            4,
            {"mode": "place_inside"},
            [
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (3, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            12,
            {"mode": "place68"},
            [],
            (6, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            12,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (3, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (2, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            2,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (4, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (1, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            3,
            {"mode": "place68"},
            [],
            (1, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (4, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            9,
            9,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            9,
            {"mode": "place68"},
            [Place(6, amount=12.0), Place(8, amount=12.0)],
            (5, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (2, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            4,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (4, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            10,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (5, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            12,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
            ],
            (4, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            6,
            3,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (1, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            6,
            5,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (1, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "takedown"},
            [],
            (6, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (5, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (4, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            10,
            10,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (6, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            10,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
            ],
            (2, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place_inside"},
            [],
            (1, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            10,
            10,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (6, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            10,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            10,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            10,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (5, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            10,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (5, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            10,
            4,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (2, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            5,
            5,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            10,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            5,
            {"mode": "place68"},
            [Place(6, amount=12.0), Place(8, amount=12.0)],
            (4, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            6,
            {"mode": "place68"},
            [Place(8, amount=12.0)],
            (2, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (4, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (2, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            8,
            {"mode": "place68"},
            [Place(6, amount=12.0)],
            (4, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (2, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            8,
            {"mode": "place68"},
            [Place(6, amount=12.0)],
            (3, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            11,
            {"mode": "place68"},
            [],
            (6, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            11,
            {"mode": "place68"},
            [],
            (6, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (1, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (4, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            6,
            {"mode": "place68"},
            [Place(8, amount=12.0)],
            (3, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (3, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            8,
            {"mode": "place68"},
            [Place(6, amount=12.0)],
            (4, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (3, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (2, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (5, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            4,
            4,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (3, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            10,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            3,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            10,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (5, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (3, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            3,
            {"mode": "place68"},
            [],
            (2, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (6, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (2, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (2, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            5,
            5,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            5,
            {"mode": "place68"},
            [Place(6, amount=12.0), Place(8, amount=12.0)],
            (2, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (3, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            10,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (1, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (4, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (1, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            3,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (1, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (6, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            4,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            3,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (2, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (4, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            8,
            {"mode": "place68"},
            [Place(6, amount=12.0)],
            (5, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            5,
            5,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (3, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            10,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            12,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (3, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (2, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            6,
            {"mode": "place68"},
            [Place(8, amount=12.0)],
            (1, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            6,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(8, amount=12.0),
            ],
            (3, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            8,
            2,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (1, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place_inside"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            4,
            4,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (1, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            6,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(8, amount=12.0),
            ],
            (4, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            4,
            9,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
            ],
            (6, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            8,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (5, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            5,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (4, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            11,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (6, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            10,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (5, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            3,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (2, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            8,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (6, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            10,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (4, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            6,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (2, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            3,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (1, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            12,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            2,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (1, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            4,
            5,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
            (1, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "takedown"},
            [],
            (2, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (6, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (6, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (2, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (2, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            6,
            {"mode": "place68"},
            [Place(8, amount=12.0)],
            (1, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            5,
            5,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (1, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            5,
            {"mode": "place68"},
            [Place(6, amount=12.0), Place(8, amount=12.0)],
            (2, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            12,
            {"mode": "place68"},
            [],
            (6, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            9,
            9,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (6, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            9,
            4,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (2, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            9,
            6,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(8, amount=12.0),
            ],
            (3, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            9,
            8,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(9, amount=5.0),
            ],
            (4, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "takedown"},
            [],
            (6, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (3, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (4, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            11,
            {"mode": "place68"},
            [],
            (6, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            10,
            10,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            10,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            10,
            {"mode": "place68"},
            [Place(6, amount=12.0), Place(8, amount=12.0)],
            (5, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (1, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            5,
            5,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (3, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (5, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            5,
            {"mode": "place68"},
            [Place(6, amount=12.0), Place(8, amount=12.0)],
            (3, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            5,
            5,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (2, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            12,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
            ],
            (4, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            5,
            12,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            5,
            9,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
            ],
            (4, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
            ],
        ),
        (
            None,
            5,
            {"mode": "takedown"},
            [],
            (3, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            9,
            9,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (6, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            9,
            6,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(8, amount=12.0),
            ],
            (1, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            9,
            2,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (1, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            9,
            6,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(5, amount=5.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (2, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
            ],
        ),
        (
            9,
            5,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
            ],
            (4, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
            ],
        ),
        (
            9,
            5,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
            ],
            (2, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
            ],
        ),
        (
            9,
            12,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "takedown"},
            [],
            (3, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            5,
            5,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (2, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (4, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            5,
            {"mode": "place68"},
            [Place(6, amount=12.0), Place(8, amount=12.0)],
            (3, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
            ],
            (2, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            6,
            5,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (4, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
        ),
        (
            None,
            6,
            {"mode": "takedown"},
            [],
            (5, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (6, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            4,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (2, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            4,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (2, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (5, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            8,
            {"mode": "place68"},
            [Place(6, amount=12.0)],
            (2, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            4,
            4,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (1, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
            ],
            (6, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            4,
            6,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(5, amount=5.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (3, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "takedown"},
            [],
            (3, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (2, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            10,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (4, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            2,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            12,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            6,
            {"mode": "place68"},
            [Place(8, amount=12.0)],
            (1, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            10,
            10,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            10,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (1, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            4,
            4,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (1, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
            ],
            (5, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place_inside"},
            [],
            (6, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (4, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (3, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            3,
            {"mode": "place68"},
            [],
            (1, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            10,
            10,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (6, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            10,
            4,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (6, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            9,
            9,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            9,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (4, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            9,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (1, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            9,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
            ],
            (2, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place_inside"},
            [],
            (1, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            4,
            4,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (2, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (4, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            4,
            {"mode": "place68"},
            [Place(6, amount=12.0), Place(8, amount=12.0)],
            (2, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            3,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (2, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            6,
            {"mode": "place68"},
            [Place(8, amount=12.0)],
            (5, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            8,
            8,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (6, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (4, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            8,
            12,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 8, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (3, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            6,
            {"mode": "place68"},
            [Place(8, amount=12.0)],
            (5, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            9,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
            ],
            (6, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            6,
            2,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (1, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            6,
            9,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
            ],
            (5, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
        ),
        (
            6,
            5,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
            (3, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
        ),
        (
            6,
            4,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
            (2, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
        ),
        (
            6,
            8,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
            (3, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
        ),
        (
            6,
            4,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
            (2, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "takedown"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            2,
            {"mode": "place68"},
            [],
            (1, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (6, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            11,
            {"mode": "place68"},
            [],
            (6, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
            ],
            (3, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place_inside"},
            [],
            (3, 4),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            9,
            9,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (3, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (1, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            3,
            {"mode": "place68"},
            [],
            (2, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            4,
            4,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (1, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            3,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (2, 1),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            11,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            5,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (3, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            4,
            6,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(8, amount=12.0),
            ],
            (1, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 4, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            None,
            4,
            {"mode": "place_inside"},
            [
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
            (1, 3),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            6,
            6,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (3, 3),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            12,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            6,
            4,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (2, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 6, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            10,
            10,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            10,
            8,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
            ],
            (6, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
                Place(9, amount=5.0),
            ],
        ),
        (
            10,
            9,
            {"mode": "place_inside"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(5, amount=5.0),
                Place(6, amount=6.0),
                Place(8, amount=6.0),
            ],
            (4, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
            ],
        ),
        (
            10,
            12,
            {"mode": "takedown"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
            ],
            (6, 6),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "takedown"},
            [],
            (2, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (1, 6),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            10,
            10,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (6, 1),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            5,
            5,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (3, 2),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            5,
            10,
            {"mode": "place68"},
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
            (6, 4),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 5, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (5, 2),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            9,
            9,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (4, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 9, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
        (
            None,
            7,
            {"mode": "place68"},
            [],
            (2, 5),
            [PassLine(amount=5.0), DontPass(amount=5.0)],
        ),
        (
            10,
            10,
            {"mode": "place68"},
            [PassLine(amount=5.0), DontPass(amount=5.0)],
            (5, 5),
            [
                PassLine(amount=5.0),
                DontPass(amount=5.0),
                Odds(DontPass, 10, amount=30.0),
                Place(6, amount=12.0),
                Place(8, amount=12.0),
            ],
        ),
    ],
)
def test_hammerlock_integration(
    point, last_roll, strat_info, bets_before, dice_result, bets_after
):
    table = Table()
    table.point.number = point
    table.last_roll = last_roll
    strategy = HammerLock(5)
    if strat_info is None:
        strat_info = {"mode": "place68"}
    if (
        table.point.status == "On"
        and strat_info["mode"] == "place68"
        and (
            Place(6, 12) not in bets_before
            and Place(8, 12) in bets_before
            or Place(8, 12) not in bets_before
            and Place(6, 12) in bets_before
        )
    ):
        strategy.place_win_count = 1
    elif (
        table.point.status == "On"
        and strat_info["mode"] == "place_inside"
        and (
            Place(5, 5) not in bets_before
            or Place(6, 6) not in bets_before
            or Place(8, 6) not in bets_before
            or Place(9, 5) not in bets_before
        )
    ):
        strategy.place_win_count = 2
    elif strat_info["mode"] == "takedown":
        strategy.place_win_count = 2
    elif table.point.status == "On" and strat_info["mode"] == "place_inside":
        strategy.place_win_count = 1
    table.add_player(bankroll=float("inf"), strategy=strategy)  # ADD STRATEGY HERE
    table.players[0].bets = bets_before
    table.dice.result = dice_result
    strategy.after_roll(table.players[0])
    TableUpdate().run_strategies(table)
    assert set(table.players[0].bets) == set(bets_after)
